# Primary Authors
- [Rico Koschmitzy](https://github.com/rkoschmitzky)
- [Dennis Weil](https://github.com/dennisweil)

# Contributions
- [Salvador Olmos Miralles](https://github.com/salvaom)
- [Alf Kraus](https://github.com/99alfie)
- Pedro Zuñeda
- [Fridtjof Kühn](https://github.com/Fridi-K)

